@@ -16,12 +16,11 @@ import numpy as np
 import pytest
 import pytz
 
-from pandas._libs import iNaT, lib, missing as libmissing
+from pandas._libs import lib, missing as libmissing
 import pandas.util._test_decorators as td
 
 from pandas.core.dtypes import inference
 from pandas.core.dtypes.common import (
-    ensure_categorical,
     ensure_int32,
     is_bool,
     is_datetime64_any_dtype,
@@ -50,7 +49,6 @@ from pandas import (
     Timedelta,
     TimedeltaIndex,
     Timestamp,
-    isna,
 )
 import pandas._testing as tm
 from pandas.core.arrays import IntegerArray
@@ -125,6 +123,17 @@ def test_is_list_like_disallow_sets(maybe_list_like):
     assert inference.is_list_like(obj, allow_sets=False) == expected
 
 
+def test_is_list_like_recursion():
+    # GH 33721
+    # interpreter would crash with with SIGABRT
+    def foo():
+        inference.is_list_like([])
+        foo()
+
+    with pytest.raises(RecursionError):
+        foo()
+
+
 def test_is_sequence():
     is_seq = inference.is_sequence
     assert is_seq((1, 2))
@@ -356,71 +365,69 @@ def test_is_recompilable_fails(ll):
 
 
 class TestInference:
-    def test_infer_dtype_bytes(self):
-        compare = "bytes"
+    @pytest.mark.parametrize(
+        "arr",
+        [
+            np.array(list("abc"), dtype="S1"),
+            np.array(list("abc"), dtype="S1").astype(object),
+            [b"a", np.nan, b"c"],
+        ],
+    )
+    def test_infer_dtype_bytes(self, arr):
+        result = lib.infer_dtype(arr, skipna=True)
+        assert result == "bytes"
 
-        # string array of bytes
-        arr = np.array(list("abc"), dtype="S1")
-        assert lib.infer_dtype(arr, skipna=True) == compare
-
-        # object array of bytes
-        arr = arr.astype(object)
-        assert lib.infer_dtype(arr, skipna=True) == compare
-
-        # object array of bytes with missing values
-        assert lib.infer_dtype([b"a", np.nan, b"c"], skipna=True) == compare
-
-    def test_isinf_scalar(self):
+    @pytest.mark.parametrize(
+        "value, expected",
+        [
+            (float("inf"), True),
+            (np.inf, True),
+            (-np.inf, False),
+            (1, False),
+            ("a", False),
+        ],
+    )
+    def test_isposinf_scalar(self, value, expected):
         # GH 11352
-        assert libmissing.isposinf_scalar(float("inf"))
-        assert libmissing.isposinf_scalar(np.inf)
-        assert not libmissing.isposinf_scalar(-np.inf)
-        assert not libmissing.isposinf_scalar(1)
-        assert not libmissing.isposinf_scalar("a")
+        result = libmissing.isposinf_scalar(value)
+        assert result is expected
 
-        assert libmissing.isneginf_scalar(float("-inf"))
-        assert libmissing.isneginf_scalar(-np.inf)
-        assert not libmissing.isneginf_scalar(np.inf)
-        assert not libmissing.isneginf_scalar(1)
-        assert not libmissing.isneginf_scalar("a")
+    @pytest.mark.parametrize(
+        "value, expected",
+        [
+            (float("-inf"), True),
+            (-np.inf, True),
+            (np.inf, False),
+            (1, False),
+            ("a", False),
+        ],
+    )
+    def test_isneginf_scalar(self, value, expected):
+        result = libmissing.isneginf_scalar(value)
+        assert result is expected
 
-    @pytest.mark.parametrize("maybe_int", [True, False])
+    @pytest.mark.parametrize("coerce_numeric", [True, False])
     @pytest.mark.parametrize(
         "infinity", ["inf", "inF", "iNf", "Inf", "iNF", "InF", "INf", "INF"]
     )
-    def test_maybe_convert_numeric_infinities(self, infinity, maybe_int):
+    @pytest.mark.parametrize("prefix", ["", "-", "+"])
+    def test_maybe_convert_numeric_infinities(self, coerce_numeric, infinity, prefix):
         # see gh-13274
-        na_values = {"", "NULL", "nan"}
-
-        pos = np.array(["inf"], dtype=np.float64)
-        neg = np.array(["-inf"], dtype=np.float64)
+        result = lib.maybe_convert_numeric(
+            np.array([prefix + infinity], dtype=object),
+            na_values={"", "NULL", "nan"},
+            coerce_numeric=coerce_numeric,
+        )
+        expected = np.array([np.inf if prefix in ["", "+"] else -np.inf])
+        tm.assert_numpy_array_equal(result, expected)
 
+    def test_maybe_convert_numeric_infinities_raises(self):
         msg = "Unable to parse string"
-
-        out = lib.maybe_convert_numeric(
-            np.array([infinity], dtype=object), na_values, maybe_int
-        )
-        tm.assert_numpy_array_equal(out, pos)
-
-        out = lib.maybe_convert_numeric(
-            np.array(["-" + infinity], dtype=object), na_values, maybe_int
-        )
-        tm.assert_numpy_array_equal(out, neg)
-
-        out = lib.maybe_convert_numeric(
-            np.array([infinity], dtype=object), na_values, maybe_int
-        )
-        tm.assert_numpy_array_equal(out, pos)
-
-        out = lib.maybe_convert_numeric(
-            np.array(["+" + infinity], dtype=object), na_values, maybe_int
-        )
-        tm.assert_numpy_array_equal(out, pos)
-
-        # too many characters
         with pytest.raises(ValueError, match=msg):
             lib.maybe_convert_numeric(
-                np.array(["foo_" + infinity], dtype=object), na_values, maybe_int
+                np.array(["foo_inf"], dtype=object),
+                na_values={"", "NULL", "nan"},
+                coerce_numeric=False,
             )
 
     def test_maybe_convert_numeric_post_floatify_nan(self, coerce):
@@ -507,6 +514,13 @@ class TestInference:
         result = lib.maybe_convert_numeric(case, set(), coerce_numeric=coerce)
         tm.assert_almost_equal(result, expected)
 
+    def test_convert_numeric_string_uint64(self):
+        # GH32394
+        result = lib.maybe_convert_numeric(
+            np.array(["uint64"], dtype=object), set(), coerce_numeric=True
+        )
+        assert np.isnan(result)
+
     @pytest.mark.parametrize("value", [-(2 ** 63) - 1, 2 ** 64])
     def test_convert_int_overflow(self, value):
         # see gh-18584
@@ -568,6 +582,13 @@ class TestInference:
 
         tm.assert_extension_array_equal(result, exp)
 
+    def test_maybe_convert_objects_bool_nan(self):
+        # GH32146
+        ind = pd.Index([True, False, np.nan], dtype=object)
+        exp = np.array([True, False, np.nan], dtype=object)
+        out = lib.maybe_convert_objects(ind.values, safe=1)
+        tm.assert_numpy_array_equal(out, exp)
+
     def test_mixed_dtypes_remain_object_array(self):
         # GH14956
         array = np.array([datetime(2015, 1, 1, tzinfo=pytz.utc), 1], dtype=object)
@@ -770,107 +791,90 @@ class TestTypeInference:
         index = Index(dates)
         assert index.inferred_type == "datetime64"
 
-    def test_infer_dtype_datetime(self):
-
-        arr = np.array([Timestamp("2011-01-01"), Timestamp("2011-01-02")])
-        assert lib.infer_dtype(arr, skipna=True) == "datetime"
-
+    def test_infer_dtype_datetime64(self):
         arr = np.array(
             [np.datetime64("2011-01-01"), np.datetime64("2011-01-01")], dtype=object
         )
         assert lib.infer_dtype(arr, skipna=True) == "datetime64"
 
-        arr = np.array([datetime(2011, 1, 1), datetime(2012, 2, 1)])
-        assert lib.infer_dtype(arr, skipna=True) == "datetime"
-
+    @pytest.mark.parametrize("na_value", [pd.NaT, np.nan])
+    def test_infer_dtype_datetime64_with_na(self, na_value):
         # starts with nan
-        for n in [pd.NaT, np.nan]:
-            arr = np.array([n, pd.Timestamp("2011-01-02")])
-            assert lib.infer_dtype(arr, skipna=True) == "datetime"
+        arr = np.array([na_value, np.datetime64("2011-01-02")])
+        assert lib.infer_dtype(arr, skipna=True) == "datetime64"
 
-            arr = np.array([n, np.datetime64("2011-01-02")])
-            assert lib.infer_dtype(arr, skipna=True) == "datetime64"
+        arr = np.array([na_value, np.datetime64("2011-01-02"), na_value])
+        assert lib.infer_dtype(arr, skipna=True) == "datetime64"
 
-            arr = np.array([n, datetime(2011, 1, 1)])
-            assert lib.infer_dtype(arr, skipna=True) == "datetime"
-
-            arr = np.array([n, pd.Timestamp("2011-01-02"), n])
-            assert lib.infer_dtype(arr, skipna=True) == "datetime"
-
-            arr = np.array([n, np.datetime64("2011-01-02"), n])
-            assert lib.infer_dtype(arr, skipna=True) == "datetime64"
-
-            arr = np.array([n, datetime(2011, 1, 1), n])
-            assert lib.infer_dtype(arr, skipna=True) == "datetime"
-
-        # different type of nat
-        arr = np.array(
-            [np.timedelta64("nat"), np.datetime64("2011-01-02")], dtype=object
-        )
+    @pytest.mark.parametrize(
+        "arr",
+        [
+            np.array(
+                [np.timedelta64("nat"), np.datetime64("2011-01-02")], dtype=object
+            ),
+            np.array(
+                [np.datetime64("2011-01-02"), np.timedelta64("nat")], dtype=object
+            ),
+            np.array([np.datetime64("2011-01-01"), pd.Timestamp("2011-01-02")]),
+            np.array([pd.Timestamp("2011-01-02"), np.datetime64("2011-01-01")]),
+            np.array([np.nan, pd.Timestamp("2011-01-02"), 1.1]),
+            np.array([np.nan, "2011-01-01", pd.Timestamp("2011-01-02")]),
+            np.array([np.datetime64("nat"), np.timedelta64(1, "D")], dtype=object),
+            np.array([np.timedelta64(1, "D"), np.datetime64("nat")], dtype=object),
+        ],
+    )
+    def test_infer_datetimelike_dtype_mixed(self, arr):
         assert lib.infer_dtype(arr, skipna=False) == "mixed"
 
-        arr = np.array(
-            [np.datetime64("2011-01-02"), np.timedelta64("nat")], dtype=object
-        )
-        assert lib.infer_dtype(arr, skipna=False) == "mixed"
-
-        # mixed datetime
-        arr = np.array([datetime(2011, 1, 1), pd.Timestamp("2011-01-02")])
-        assert lib.infer_dtype(arr, skipna=True) == "datetime"
-
-        # should be datetime?
-        arr = np.array([np.datetime64("2011-01-01"), pd.Timestamp("2011-01-02")])
-        assert lib.infer_dtype(arr, skipna=True) == "mixed"
-
-        arr = np.array([pd.Timestamp("2011-01-02"), np.datetime64("2011-01-01")])
-        assert lib.infer_dtype(arr, skipna=True) == "mixed"
-
+    def test_infer_dtype_mixed_integer(self):
         arr = np.array([np.nan, pd.Timestamp("2011-01-02"), 1])
         assert lib.infer_dtype(arr, skipna=True) == "mixed-integer"
 
-        arr = np.array([np.nan, pd.Timestamp("2011-01-02"), 1.1])
-        assert lib.infer_dtype(arr, skipna=True) == "mixed"
-
-        arr = np.array([np.nan, "2011-01-01", pd.Timestamp("2011-01-02")])
-        assert lib.infer_dtype(arr, skipna=True) == "mixed"
-
-    def test_infer_dtype_timedelta(self):
-
-        arr = np.array([pd.Timedelta("1 days"), pd.Timedelta("2 days")])
-        assert lib.infer_dtype(arr, skipna=True) == "timedelta"
-
-        arr = np.array([np.timedelta64(1, "D"), np.timedelta64(2, "D")], dtype=object)
-        assert lib.infer_dtype(arr, skipna=True) == "timedelta"
-
-        arr = np.array([timedelta(1), timedelta(2)])
-        assert lib.infer_dtype(arr, skipna=True) == "timedelta"
+    @pytest.mark.parametrize(
+        "arr",
+        [
+            np.array([Timestamp("2011-01-01"), Timestamp("2011-01-02")]),
+            np.array([datetime(2011, 1, 1), datetime(2012, 2, 1)]),
+            np.array([datetime(2011, 1, 1), pd.Timestamp("2011-01-02")]),
+        ],
+    )
+    def test_infer_dtype_datetime(self, arr):
+        assert lib.infer_dtype(arr, skipna=True) == "datetime"
 
+    @pytest.mark.parametrize("na_value", [pd.NaT, np.nan])
+    @pytest.mark.parametrize(
+        "time_stamp", [pd.Timestamp("2011-01-01"), datetime(2011, 1, 1)]
+    )
+    def test_infer_dtype_datetime_with_na(self, na_value, time_stamp):
         # starts with nan
-        for n in [pd.NaT, np.nan]:
-            arr = np.array([n, Timedelta("1 days")])
-            assert lib.infer_dtype(arr, skipna=True) == "timedelta"
+        arr = np.array([na_value, time_stamp])
+        assert lib.infer_dtype(arr, skipna=True) == "datetime"
 
-            arr = np.array([n, np.timedelta64(1, "D")])
-            assert lib.infer_dtype(arr, skipna=True) == "timedelta"
+        arr = np.array([na_value, time_stamp, na_value])
+        assert lib.infer_dtype(arr, skipna=True) == "datetime"
 
-            arr = np.array([n, timedelta(1)])
-            assert lib.infer_dtype(arr, skipna=True) == "timedelta"
+    @pytest.mark.parametrize(
+        "arr",
+        [
+            np.array([pd.Timedelta("1 days"), pd.Timedelta("2 days")]),
+            np.array([np.timedelta64(1, "D"), np.timedelta64(2, "D")], dtype=object),
+            np.array([timedelta(1), timedelta(2)]),
+        ],
+    )
+    def test_infer_dtype_timedelta(self, arr):
+        assert lib.infer_dtype(arr, skipna=True) == "timedelta"
 
-            arr = np.array([n, pd.Timedelta("1 days"), n])
-            assert lib.infer_dtype(arr, skipna=True) == "timedelta"
+    @pytest.mark.parametrize("na_value", [pd.NaT, np.nan])
+    @pytest.mark.parametrize(
+        "delta", [Timedelta("1 days"), np.timedelta64(1, "D"), timedelta(1)]
+    )
+    def test_infer_dtype_timedelta_with_na(self, na_value, delta):
+        # starts with nan
+        arr = np.array([na_value, delta])
+        assert lib.infer_dtype(arr, skipna=True) == "timedelta"
 
-            arr = np.array([n, np.timedelta64(1, "D"), n])
-            assert lib.infer_dtype(arr, skipna=True) == "timedelta"
-
-            arr = np.array([n, timedelta(1), n])
-            assert lib.infer_dtype(arr, skipna=True) == "timedelta"
-
-        # different type of nat
-        arr = np.array([np.datetime64("nat"), np.timedelta64(1, "D")], dtype=object)
-        assert lib.infer_dtype(arr, skipna=False) == "mixed"
-
-        arr = np.array([np.timedelta64(1, "D"), np.datetime64("nat")], dtype=object)
-        assert lib.infer_dtype(arr, skipna=False) == "mixed"
+        arr = np.array([na_value, delta, na_value])
+        assert lib.infer_dtype(arr, skipna=True) == "timedelta"
 
     def test_infer_dtype_period(self):
         # GH 13664
@@ -880,24 +884,25 @@ class TestTypeInference:
         arr = np.array([pd.Period("2011-01", freq="D"), pd.Period("2011-02", freq="M")])
         assert lib.infer_dtype(arr, skipna=True) == "period"
 
-        # starts with nan
-        for n in [pd.NaT, np.nan]:
-            arr = np.array([n, pd.Period("2011-01", freq="D")])
-            assert lib.infer_dtype(arr, skipna=True) == "period"
+    def test_infer_dtype_period_mixed(self):
+        arr = np.array(
+            [pd.Period("2011-01", freq="M"), np.datetime64("nat")], dtype=object
+        )
+        assert lib.infer_dtype(arr, skipna=False) == "mixed"
 
-            arr = np.array([n, pd.Period("2011-01", freq="D"), n])
-            assert lib.infer_dtype(arr, skipna=True) == "period"
-
-        # different type of nat
         arr = np.array(
             [np.datetime64("nat"), pd.Period("2011-01", freq="M")], dtype=object
         )
         assert lib.infer_dtype(arr, skipna=False) == "mixed"
 
-        arr = np.array(
-            [pd.Period("2011-01", freq="M"), np.datetime64("nat")], dtype=object
-        )
-        assert lib.infer_dtype(arr, skipna=False) == "mixed"
+    @pytest.mark.parametrize("na_value", [pd.NaT, np.nan])
+    def test_infer_dtype_period_with_na(self, na_value):
+        # starts with nan
+        arr = np.array([na_value, pd.Period("2011-01", freq="D")])
+        assert lib.infer_dtype(arr, skipna=True) == "period"
+
+        arr = np.array([na_value, pd.Period("2011-01", freq="D"), na_value])
+        assert lib.infer_dtype(arr, skipna=True) == "period"
 
     @pytest.mark.parametrize(
         "data",
@@ -1101,6 +1106,21 @@ class TestTypeInference:
         result = lib.infer_dtype(dates, skipna=True)
         assert result == "date"
 
+    @pytest.mark.parametrize(
+        "values",
+        [
+            [date(2020, 1, 1), pd.Timestamp("2020-01-01")],
+            [pd.Timestamp("2020-01-01"), date(2020, 1, 1)],
+            [date(2020, 1, 1), pd.NaT],
+            [pd.NaT, date(2020, 1, 1)],
+        ],
+    )
+    @pytest.mark.parametrize("skipna", [True, False])
+    def test_infer_dtype_date_order_invariant(self, values, skipna):
+        # https://github.com/pandas-dev/pandas/issues/33741
+        result = lib.infer_dtype(values, skipna=skipna)
+        assert result == "date"
+
     def test_is_numeric_array(self):
 
         assert lib.is_float_array(np.array([1, 2.0]))
@@ -1200,6 +1220,24 @@ class TestTypeInference:
         inferred = lib.infer_dtype(pd.Series(idx), skipna=False)
         assert inferred == "interval"
 
+    @pytest.mark.parametrize("klass", [pd.array, pd.Series])
+    @pytest.mark.parametrize("skipna", [True, False])
+    @pytest.mark.parametrize("data", [["a", "b", "c"], ["a", "b", pd.NA]])
+    def test_string_dtype(self, data, skipna, klass):
+        # StringArray
+        val = klass(data, dtype="string")
+        inferred = lib.infer_dtype(val, skipna=skipna)
+        assert inferred == "string"
+
+    @pytest.mark.parametrize("klass", [pd.array, pd.Series])
+    @pytest.mark.parametrize("skipna", [True, False])
+    @pytest.mark.parametrize("data", [[True, False, True], [True, False, pd.NA]])
+    def test_boolean_dtype(self, data, skipna, klass):
+        # BooleanArray
+        val = klass(data, dtype="boolean")
+        inferred = lib.infer_dtype(val, skipna=skipna)
+        assert inferred == "boolean"
+
 
 class TestNumberScalar:
     def test_is_number(self):
@@ -1208,7 +1246,6 @@ class TestNumberScalar:
         assert is_number(1)
         assert is_number(1.1)
         assert is_number(1 + 3j)
-        assert is_number(np.bool(False))
         assert is_number(np.int64(1))
         assert is_number(np.float64(1.1))
         assert is_number(np.complex128(1 + 3j))
@@ -1229,7 +1266,7 @@ class TestNumberScalar:
 
     def test_is_bool(self):
         assert is_bool(True)
-        assert is_bool(np.bool(False))
+        assert is_bool(False)
         assert is_bool(np.bool_(False))
 
         assert not is_bool(1)
@@ -1256,7 +1293,7 @@ class TestNumberScalar:
         assert not is_integer(True)
         assert not is_integer(1.1)
         assert not is_integer(1 + 3j)
-        assert not is_integer(np.bool(False))
+        assert not is_integer(False)
         assert not is_integer(np.bool_(False))
         assert not is_integer(np.float64(1.1))
         assert not is_integer(np.complex128(1 + 3j))
@@ -1279,7 +1316,7 @@ class TestNumberScalar:
         assert not is_float(True)
         assert not is_float(1)
         assert not is_float(1 + 3j)
-        assert not is_float(np.bool(False))
+        assert not is_float(False)
         assert not is_float(np.bool_(False))
         assert not is_float(np.int64(1))
         assert not is_float(np.complex128(1 + 3j))
@@ -1346,9 +1383,11 @@ class TestIsScalar:
         assert is_scalar(None)
         assert is_scalar(True)
         assert is_scalar(False)
-        assert is_scalar(Number())
         assert is_scalar(Fraction())
         assert is_scalar(0.0)
+        assert is_scalar(1)
+        assert is_scalar(complex(2))
+        assert is_scalar(float("NaN"))
         assert is_scalar(np.nan)
         assert is_scalar("foobar")
         assert is_scalar(b"foobar")
@@ -1357,6 +1396,7 @@ class TestIsScalar:
         assert is_scalar(time(12, 0))
         assert is_scalar(timedelta(hours=1))
         assert is_scalar(pd.NaT)
+        assert is_scalar(pd.NA)
 
     def test_is_scalar_builtin_nonscalars(self):
         assert not is_scalar({})
@@ -1371,6 +1411,7 @@ class TestIsScalar:
         assert is_scalar(np.int64(1))
         assert is_scalar(np.float64(1.0))
         assert is_scalar(np.int32(1))
+        assert is_scalar(np.complex64(2))
         assert is_scalar(np.object_("foobar"))
         assert is_scalar(np.str_("foobar"))
         assert is_scalar(np.unicode_("foobar"))
@@ -1401,6 +1442,7 @@ class TestIsScalar:
         assert is_scalar(Period("2014-01-01"))
         assert is_scalar(Interval(left=0, right=1))
         assert is_scalar(DateOffset(days=1))
+        assert is_scalar(pd.offsets.Minute(3))
 
     def test_is_scalar_pandas_containers(self):
         assert not is_scalar(Series(dtype=object))
@@ -1409,6 +1451,26 @@ class TestIsScalar:
         assert not is_scalar(DataFrame([[1]]))
         assert not is_scalar(Index([]))
         assert not is_scalar(Index([1]))
+        assert not is_scalar(Categorical([]))
+        assert not is_scalar(DatetimeIndex([])._data)
+        assert not is_scalar(TimedeltaIndex([])._data)
+        assert not is_scalar(DatetimeIndex([])._data.to_period("D"))
+        assert not is_scalar(pd.array([1, 2, 3]))
+
+    def test_is_scalar_number(self):
+        # Number() is not recognied by PyNumber_Check, so by extension
+        #  is not recognized by is_scalar, but instances of non-abstract
+        #  subclasses are.
+
+        class Numeric(Number):
+            def __init__(self, value):
+                self.value = value
+
+            def __int__(self):
+                return self.value
+
+        num = Numeric(1)
+        assert is_scalar(num)
 
 
 def test_datetimeindex_from_empty_datetime64_array():
@@ -1423,14 +1485,12 @@ def test_nan_to_nat_conversions():
         dict({"A": np.asarray(range(10), dtype="float64"), "B": Timestamp("20010101")})
     )
     df.iloc[3:6, :] = np.nan
-    result = df.loc[4, "B"].value
-    assert result == iNaT
+    result = df.loc[4, "B"]
+    assert result is pd.NaT
 
     s = df["B"].copy()
-    s._data = s._data.setitem(indexer=tuple([slice(8, 9)]), value=np.nan)
-    assert isna(s[8])
-
-    assert s[8].value == np.datetime64("NaT").astype(np.int64)
+    s[8:9] = np.nan
+    assert s[8] is pd.NaT
 
 
 @td.skip_if_no_scipy
@@ -1448,13 +1508,3 @@ def test_ensure_int32():
     values = np.arange(10, dtype=np.int64)
     result = ensure_int32(values)
     assert result.dtype == np.int32
-
-
-def test_ensure_categorical():
-    values = np.arange(10, dtype=np.int32)
-    result = ensure_categorical(values)
-    assert result.dtype == "category"
-
-    values = Categorical(values)
-    result = ensure_categorical(values)
-    tm.assert_categorical_equal(result, values)
